"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports["default"] = getOffset;

var _ownerDocument = _interopRequireDefault(require("./ownerDocument.js"));

var _getWindow = _interopRequireDefault(require("./getWindow.js"));

var _contains = _interopRequireDefault(require("./contains.js"));

/**
 * Get the offset of a DOM element
 * @param node The DOM element
 * @returns The offset of the DOM element
 */
function getOffset(node) {
  var doc = (0, _ownerDocument["default"])(node);
  var win = (0, _getWindow["default"])(doc);
  var docElem = doc && doc.documentElement;
  var box = {
    top: 0,
    left: 0,
    height: 0,
    width: 0
  };

  if (!doc) {
    return null;
  } // Make sure it's not a disconnected DOM node


  if (!(0, _contains["default"])(docElem, node)) {
    return box;
  }

  if ((node === null || node === void 0 ? void 0 : node.getBoundingClientRect) !== undefined) {
    box = node.getBoundingClientRect();
  }

  if ((box.width || box.height) && docElem && win) {
    box = {
      top: box.top + (win.pageYOffset || docElem.scrollTop) - (docElem.clientTop || 0),
      left: box.left + (win.pageXOffset || docElem.scrollLeft) - (docElem.clientLeft || 0),
      width: (box.width === null ? node.offsetWidth : box.width) || 0,
      height: (box.height === null ? node.offsetHeight : box.height) || 0
    };
  }

  return box;
}

module.exports = exports.default;