"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports["default"] = getPosition;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _getOffsetParent = _interopRequireDefault(require("./getOffsetParent.js"));

var _getOffset = _interopRequireDefault(require("./getOffset.js"));

var _getStyle = _interopRequireDefault(require("./getStyle.js"));

var _scrollTop = _interopRequireDefault(require("./scrollTop.js"));

var _scrollLeft = _interopRequireDefault(require("./scrollLeft.js"));

var _nodeName = _interopRequireDefault(require("./nodeName.js"));

/**
 * Get the position of a DOM element
 * @param node  The DOM element
 * @param offsetParent  The offset parent of the DOM element
 * @param calcMargin  Whether to calculate the margin
 * @returns  The position of the DOM element
 */
function getPosition(node, offsetParent, calcMargin) {
  if (calcMargin === void 0) {
    calcMargin = true;
  }

  var parentOffset = {
    top: 0,
    left: 0
  };
  var offset = null; // Fixed elements are offset from window (parentOffset = {top:0, left: 0},
  // because it is its only offset parent

  if ((0, _getStyle["default"])(node, 'position') === 'fixed') {
    offset = node.getBoundingClientRect();
  } else {
    offsetParent = offsetParent || (0, _getOffsetParent["default"])(node);
    offset = (0, _getOffset["default"])(node);

    if ((0, _nodeName["default"])(offsetParent) !== 'html') {
      var nextParentOffset = (0, _getOffset["default"])(offsetParent);

      if (nextParentOffset) {
        parentOffset.top = nextParentOffset.top;
        parentOffset.left = nextParentOffset.left;
      }
    }

    parentOffset.top += parseInt((0, _getStyle["default"])(offsetParent, 'borderTopWidth'), 10) - (0, _scrollTop["default"])(offsetParent) || 0;
    parentOffset.left += parseInt((0, _getStyle["default"])(offsetParent, 'borderLeftWidth'), 10) - (0, _scrollLeft["default"])(offsetParent) || 0;
  } // Subtract parent offsets and node margins


  if (offset) {
    var marginTop = calcMargin ? parseInt((0, _getStyle["default"])(node, 'marginTop'), 10) || 0 : 0;
    var marginLeft = calcMargin ? parseInt((0, _getStyle["default"])(node, 'marginLeft'), 10) || 0 : 0;
    return (0, _extends2["default"])({}, offset, {
      top: offset.top - parentOffset.top - marginTop,
      left: offset.left - parentOffset.left - marginLeft
    });
  }

  return null;
}

module.exports = exports.default;